@@ -2,7 +2,7 @@
 # Copyright (C) 1997 Ken MacLeod
 # See the file COPYING for distribution terms.
 #
-# $Id: HTML.pm,v 1.2 1997/10/24 18:54:11 ken Exp $
+# $Id: HTML.pm,v 1.4 1997/11/03 17:46:46 ken Exp $
 #
 
 use Class::Visitor;
@@ -13,6 +13,7 @@ visitor_class 'Quilt::HTML', 'Quilt', {};
 
 visitor_class 'Quilt::HTML::Title', 'Quilt', {
     contents => '@',
+    id => '$',
     level => '$',
     quadding => '$',
 };
@@ -29,7 +30,9 @@ visitor_class 'Quilt::HTML::Anchor', 'Quilt::Flow', {
     url => '@',
 };
 
-visitor_class 'Quilt::HTML::Table', 'Quilt::Flow', {};
+visitor_class 'Quilt::HTML::Table', 'Quilt::Flow', {
+    frame => '$',
+};
 visitor_class 'Quilt::HTML::Table::Row', 'Quilt::Flow', {};
 visitor_class 'Quilt::HTML::Table::Data', 'Quilt::Flow', {};
 
